@@ -101,8 +101,8 @@ __TLDS = R'(?:{possible_tld})(?!(?:{dealbreakers}))'.format(
     ])
 )
 
-format_domain_normal = R'\b(?:[a-z0-9\-\_]{{1,256}}?\.){repeat}[a-z0-9\-\_]{{1,256}}\.{tlds}'
-format_domain_defang = R'\b(?:[a-z0-9\-\_]{{1,256}}?(?:\[\.\]|\.)){repeat}[a-z0-9\-\_]{{1,256}}(?:\[\.\]|\.){tlds}'
+format_domain_normal = R'\b(?:[a-z0-9\_][a-z0-9\-\_]{{0,256}}?\.){repeat}[a-z0-9\_][a-z0-9\-\_]{{1,256}}\.{tlds}'
+format_domain_defang = R'\b(?:[a-z0-9\_][a-z0-9\-\_]{{0,256}}?(?:\[\.\]|\.)){repeat}[a-z0-9\_][a-z0-9\-\_]{{1,256}}(?:\[\.\]|\.){tlds}'
 
 pattern_domain = format_domain_normal.format(repeat='{0,20}', tlds=__TLDS)
 
@@ -199,7 +199,7 @@ class formats(PatternEnum):
     "Base64 encoded strings"
     b64u = alphabet(R'[0-9a-zA-Z\_\-]', postfix=R'[0-9a-zA-Z\_\-]{0,3}={0,3}', ignore_case=False)
     "Base64 encoded strings using URL-safe alphabet"
-    hex = alphabet(R'[0-9a-f]')
+    hex = alphabet(R'[0-9a-fA-F]')
     "Hexadecimal strings"
     HEX = alphabet(R'[0-9A-F]', ignore_case=False)
     "Uppercase hexadecimal strings"
