@@ -18,7 +18,7 @@ class defang(Unit):
     def interface(self, argp):
         argp.add_argument('-q', '--quote', action='store_true', help='Wrap all indicators in backticks for markdown code.')
         argp.add_argument('-u', '--url-only', action='store_true', help='Only defang URLs, do not look for domains or IPs.')
-        argp.add_argument('-p', '--protocol', action='store_true', help='Escape the protocol colon in URLs.')
+        argp.add_argument('-d', '--dot-only', dest='protocol', action='store_false', help='Do not escape the protocol colon in URLs.')
         return super().interface(argp)
 
     def _quote(self, word):
