@@ -23,13 +23,22 @@ class xtp(PatternExtractor):
     _LEGITIMATE_HOSTS = [
         'adobe.com',
         'aka.ms',
+        'apache.org',
+        'apple.com',
+        'azure.com',
+        'curl.haxx.se',
         'digicert.com',
-        'google.com',
+        'globalsign.com',
+        'globalsign.net',
+        'iana.org',
         'live.com',
         'microsoft.com',
+        'msdn.com',
+        'msn.com',
         'office.com',
         'openssl.org',
         'openxmlformats.org',
+        'python.org',
         'skype.com',
         'sway-cdn.com',
         'sway-extensions.com',
@@ -39,7 +48,9 @@ class xtp(PatternExtractor):
         'thawte.com',
         'verisign.com',
         'w3.org',
+        'xml.org',
         'xmlsoap.org',
+        'yahoo.com',
     ]
 
     _DOMAIN_WHITELIST = [
@@ -96,7 +107,7 @@ class xtp(PatternExtractor):
             ioc = value.decode(cls.codec)
             if '://' not in ioc: ioc = F'TCP://{ioc}'
             host = urlparse(ioc).netloc.split(':', 1)[0].lower()
-            if any(host.endswith(w) for w in cls._LEGITIMATE_HOSTS):
+            if any(host == w or host.endswith(F'.{w}') for w in cls._LEGITIMATE_HOSTS):
                 return None
             if any(host == w for w in cls._DOMAIN_WHITELIST):
                 return None
