@@ -21,7 +21,6 @@ class dump(Unit):
          {md5} : MD5 hash of the data
         {sha1} : SHA1 hash of the data
       {sha256} : SHA-256 hash of the data
-        {size} : Size of the data as a human readable expression
 
     When not using formatted file names, the unit ingests as many incoming inputs
     as filenames were specified on the command line. Unless connected to a terminal,
@@ -41,7 +40,21 @@ class dump(Unit):
             help='Output file',
             metavar='file'
         )
+        argp.add_argument('-t', '--tee', action='store_true', 
+            help='Forward all inputs to STDOUT.')
+
         mode = argp.add_mutually_exclusive_group()
+        mode.add_argument('-s', '--stream', action='store_true', 
+            help='Dump all incoming inputs to the same file.')
+
+        mode.add_argument(
+            '-m', '--meta', action='store_true', help=(
+                'Automatically choose a filename. For multiple inputs, some '
+                'units provide a file name in their output; in this case, '
+                'this file name is used. Otherwise, the format {sha256} '
+                'is used as the file name.'
+            )
+        )
         mode.add_argument(
             '-f', '--format', action='store_true', help=(
                 'Provide format strings instead of a list of filenames. '
@@ -49,16 +62,7 @@ class dump(Unit):
                 'a file name for each input to be dumped.'
             )
         )
-        mode.add_argument(
-            '-s', '--stream', action='store_true', help=(
-                'Dump all incoming inputs to the same file.'
-            )
-        )
-        argp.add_argument(
-            '-t', '--tee', action='store_true', help=(
-                'Forward all inputs to STDOUT.'
-            )
-        )
+
         return super().interface(argp)
 
     def __init__(self, *args, **kw):
@@ -67,21 +71,21 @@ class dump(Unit):
 
     def _auto_extension(self, data, default='bin'):
         import re
-        from . import magic
-
-        if not isinstance(data, bytes):
-            data = bytes(data)
+        from ...lib.magic import magic, magicparse
 
         if not magic:
             self.log_warn(F'magic library not found, auto extension defaults to {default}')
             return default
 
-        mime = magic.Magic(mime=True).from_buffer(data)
+        if not isinstance(data, bytes):
+            data = bytes(data)
+
+        mime = magicparse(data, mime=True)
         mime = mime.split(';')[0].lower()
         mtype, mext = mime.split('/')
 
         if mext == 'x-dosexec':
-            description = magic.Magic().from_buffer(data)
+            description = magicparse(data)
             if re.search('executable', description):
                 return 'dll' if '(DLL)' in description else 'exe'
         try:
@@ -119,7 +123,9 @@ class dump(Unit):
     def _reset(self):
         self.stream = None
         self.exhausted = False
-        if self.args.format:
+        if self.args.meta:
+            self.iter_filenames = iter(())
+        elif self.args.format:
             self.iter_filenames = cycle(self.args.filenames)
         else:
             self.iter_filenames = iter(self.args.filenames)
@@ -128,18 +134,19 @@ class dump(Unit):
 
     @property
     def _paste(self):
-        return not bool(self.args.filenames) and not bool(self.args.format)
+        return not bool(self.args.filenames) and not bool(self.args.format) and not self.args.meta
 
-    @staticmethod
-    def _open(filename, unc=False):
+    def _open(self, filename, unc=False):
         filename = os.path.abspath(filename)
         base = os.path.dirname(filename)
+        if not unc:
+            self.log_info(filename)
         try:
             os.makedirs(base, exist_ok=True)
         except FileNotFoundError:
             if not unc and os.name == 'nt':
                 filename = F'\\\\?\\{filename}'
-                return dump._open(filename, unc=True)
+                return self._open(filename, unc=True)
             raise
         else:
             return open(filename, 'wb')
@@ -153,9 +160,6 @@ class dump(Unit):
     def _format(self, filename, data, index=0):
         class DelayedFormatter(dict):
             def __missing__(_, key):
-                if key == 'size':
-                    from ...lib.tools import format_size
-                    return format_size(len(data), explain_bytes=False, default='{}B')
                 if key == 'crc32':
                     from zlib import crc32
                     return F'{crc32(data) & 0xFFFFFFFF:08X}'
@@ -216,12 +220,18 @@ class dump(Unit):
             if not self.exhausted:
                 if not self.args.stream or not self.stream:
                     try:
-                        filename = next(self.iter_filenames)
+                        if not self.args.meta:
+                            filename = next(self.iter_filenames)
+                        else:
+                            filename = chunk['path']
+                            if not filename:
+                                import hashlib
+                                filename = hashlib.sha256(chunk).hexdigest()
                     except StopIteration:
                         self.exhausted = True
                     else:
                         if self.args.format:
-                            filename = self._format(filename, chunk.data, index + 1)
+                            filename = self._format(filename, chunk, index + 1)
                         self.stream = self._open(filename)
             yield chunk
 
